@@ -28,15 +28,16 @@ from sequana.lazy import pandas as pd
 from sequana.lazy import pylab
 
 import colorlog
-logger = colorlog.getLogger(__name__)
 
+logger = colorlog.getLogger(__name__)
 
 
 from sequana.utils.datatables_js import DataTable
 
 
 class BWABAMtoFastQModule(SequanaBaseModule):
-    """ Write HTML report of BWA mapping (phix)"""
+    """Write HTML report of BWA mapping (phix)"""
+
     def __init__(self, input_directory, output_filename=None):
         """
         :param input_directory: the directory of the bwa_bam_to_fastq output
@@ -50,41 +51,44 @@ class BWABAMtoFastQModule(SequanaBaseModule):
             self.create_html(output_filename)
 
     def create_report_content(self):
-        """ Generate the sections list to fill the HTML report.
-        """
+        """Generate the sections list to fill the HTML report."""
         self.sections = list()
         self.add_stats()
 
     def _get_html_stats(self):
         from sequana.tools import StatsBAM2Mapped
         from easydev import precision
+
         data = StatsBAM2Mapped(self.directory + "bwa_mem_stats.json").data
-        html = "Reads with Phix: %s %%<br>" % precision(data['contamination'], 3)
+        html = "Reads with Phix: %s %%<br>" % precision(data["contamination"], 3)
 
         # add HTML table
         if "R2_mapped" in data.keys():
-            df = pd.DataFrame({
-              'R1': [data['R1_mapped'], data['R1_unmapped']],
-              'R2': [data['R2_mapped'], data['R2_unmapped']]})
+            df = pd.DataFrame(
+                {
+                    "R1": [data["R1_mapped"], data["R1_unmapped"]],
+                    "R2": [data["R2_mapped"], data["R2_unmapped"]],
+                }
+            )
         else:
-            df = pd.DataFrame({
-              'R1': [data['R1_mapped'], data['R1_unmapped']]})
-        df.index = ['mapped', 'unmapped']
+            df = pd.DataFrame({"R1": [data["R1_mapped"], data["R1_unmapped"]]})
+        df.index = ["mapped", "unmapped"]
 
         datatable = DataTable(df, "bwa_bam")
         datatable.datatable.datatable_options = {
-             'scrollX': '300px',
-             'pageLength': 30,
-             'scrollCollapse': 'true',
-             'dom': 'irtpB',
-             "paging": "false",
-             'buttons': ['copy', 'csv']}
+            "scrollX": "300px",
+            "pageLength": 30,
+            "scrollCollapse": "true",
+            "dom": "irtpB",
+            "paging": "false",
+            "buttons": ["copy", "csv"],
+        }
         js = datatable.create_javascript_function()
-        html_tab = datatable.create_datatable(float_format='%.3g')
-        #html += "{} {}".format(html_tab, js)
+        html_tab = datatable.create_datatable(float_format="%.3g")
+        # html += "{} {}".format(html_tab, js)
 
-        html += "Unpaired: %s <br>" % data['unpaired']
-        html += "duplicated: %s <br>" % data['duplicated']
+        html += "Unpaired: %s <br>" % data["unpaired"]
+        html += "duplicated: %s <br>" % data["duplicated"]
         return html
 
     def _get_html_mapped_stats(self):
@@ -94,9 +98,6 @@ class BWABAMtoFastQModule(SequanaBaseModule):
     def add_stats(self):
         html1 = self._get_html_stats()
         html2 = self._get_html_mapped_stats()
-        self.sections.append({
-          "name": "Stats inputs",
-          "anchor": "stats",
-          "content": html1+html2
-        })
-
+        self.sections.append(
+            {"name": "Stats inputs", "anchor": "stats", "content": html1 + html2}
+        )
